package test.contract;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.UUID;

import test.MainTest;
import utils.HttpRequest;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

/**
 * 合同相关测试（使用模板）接口
 * @author Administrator
 *
 */
public class ContractWithTemplateTest {
	public static void main(String[] args) throws IOException {
		//合同编号是唯一
		String contractid = "自定义合同编号";
		//调用合同模板发起接口（备注：首先登录信签服务器，在模板管理程序里面维护模板）
		JSONObject json = generateContract(contractid , MainTest.CONTRACT_TPL_CODE);
		System.out.println("合同模板发起接口返回结果："+json);
		//合同创建成功
		if(json.getInteger("code") == 1){
			//下载合同文件到本地
			downFiles(json.getJSONArray("doc_last_urls"), "d:/"+contractid);
			//调用合同签署口接口
			json = signContract(contractid, MainTest.SIGNER_CODE);
			System.out.println("合同签署接口返回结果："+json);
			//签署成功
			if(json.getInteger("code") == 1){
				downFiles(json.getJSONArray("record_saved_urls"), "d:/"+contractid);
			}
		}
		
	}
	
	/**
	 * 下载多个文件保存在文件夹
	 * @param urls
	 * @param savePath
	 * @throws IOException
	 */
	public static final void downFiles(JSONArray urls , String savePath) throws IOException{
		for (Object url : urls) {
			downFile((String)url, savePath);
		}
	}
	
	/**
	 * 下载文件保存
	 * @param url
	 * @param savePath
	 * @throws IOException 
	 */
	public static final void downFile(String url , String savePath) throws IOException{
		HttpRequest request = MainTest.createHttpRequest(url);
		request.send();
		int code = request.getResponseCode();
		if(code==200){
			FileOutputStream fos = null;
			try{
				String fileName = savePath;
				if(!(savePath.endsWith("/")|| savePath.endsWith("\\"))){
					fileName +="/";
				}
				fileName+=request.getDownFileName();
				File file  = new File(fileName);
				file.getParentFile().mkdirs();
				fos = new FileOutputStream(file);
				System.out.println("保存文件至："+fileName);
				request.result(fos);
			}finally{
				if(fos!=null){
					fos.close();
				}
			}
		}else{
			System.out.println("错误信息："+request.resultToString());
		}
	}
	
	/**
	 * 使用模板创建合同
	 * @param contractid  合同编号
	 * @param contract_tpl_code 模板编号
	 * @return
	 * @throws IOException
	 */
	public static JSONObject generateContract(String contractid , String contract_tpl_code) throws IOException{
		HttpRequest request = MainTest.createHttpRequest("/api/contract/start");
		//{"姓名":"李东长","cardname_ID":"360111198708080899","year":"2018","month":"01","day":"01"}
		JSONObject xml_metadata = new JSONObject(true);
		xml_metadata.put("姓名", "李东长");
		xml_metadata.put("cardname_ID", "360111198708080899");
		xml_metadata.put("year", "2018");
		xml_metadata.put("month", "01");
		xml_metadata.put("day", "01");
		
		/*****************需要添加到合同内的附件文件,默认该参数("attach_file")的文档将作为附件添加至第一个文档，如果需要将附件附加到其他文档，
		 * 参数名称需要添加文档索引，比如"attach_file_2"表示往第二个合同文档添加附件*********************/
		//request.addFile("attach_file", new File("d:/t1.pdf"));
		
		//request.addFile("attach_file", new File("d:/t2.gif"));
		
		//request.addFile("attach_file_2", new File("d:/test.docx"));
		request.addParam("contract_tlp_code",contract_tpl_code);
		
		request.addParam("doc_metadata",xml_metadata.toJSONString());
		
		//设置合同ID
		request.addParam("contract_id", contractid);
		//设置合同名称参数
		request.addParam("contract_name", "测试合同");
		
		//设置业务编码参数
		request.addParam("biz_id", UUID.randomUUID().toString().replaceAll("-", ""));
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		//设置业务时间参数
		request.addParam("biz_time", sdf.format(new Date()));
		
		
		request.send();
		return JSONObject.parseObject(request.resultToString());
		
	}
	
	/**
	 * 签署合同
	 * @throws IOException 
	 */
	public static JSONObject signContract(String contractid , String signer_code ) throws IOException{
		HttpRequest request = MainTest.createHttpRequest("/api/contract/sign");
		request.addParam("contract_id", contractid);
		request.addParam("biz_id", UUID.randomUUID().toString().replaceAll("-", ""));
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
		//设置业务时间参数
		request.addParam("biz_time", sdf.format(new Date()));
		//设置签署人的编码
		request.addParam("signer_code", signer_code);
		
		request.send();
		return JSONObject.parseObject(request.resultToString());
		
	}
}
