package test.signer;

import java.io.IOException;

import test.MainTest;
import utils.HttpRequest;

import com.alibaba.fastjson.JSONObject;

public class SignerTest {
	public static void main(String[] args) throws IOException {

		// 基本数据
		String signer_code = MainTest.SIGNER_CODE; // 用户编码
		String signer_name = "李东长"; // 用户名称
		String signer_phone = "13037236393"; // 用户手机号码
		String seal_code = "e6432961f13d488aadada60afdceaaa1"; // 用户的印章编码
		String signer_type = "1"; // 用户类型 （1:个人,2:企业）
		String signer_pwd = "123456"; // 用户原始密码
		String signer_newpwd = "123456"; // 修改后密码

		/**
		 * 签署用户证件类型 ，默认值：0， 可选【0：居民身份证，1：护照，B：港澳居民往来内地通行证，C：台湾居民来往大陆通行证，
		 * 2：社会信用代码，3：工商登记证，4：税务登记证，7：组织机构代码证，8：企业营业执照 ，Z：其他】，实名用户不可修改此参数
		 */
		String signer_idtype = "0";

		/**
		 * 用户证件编号，实名用户不可修改此参数 增至服务接口可以实现实名认证
		 */
		String signer_idcode = "360111198708080899";



		// 【签署用户信息修改】
		JSONObject json = updateSigner(signer_code, signer_name, signer_phone, signer_type, signer_idtype,
				signer_idcode);
		System.out.println("签署用户信息修改接口："+json);
		
		// 【修改签署用户密码】
		json = updateSignerWithPwd(signer_code, signer_pwd, signer_newpwd);
		System.out.println("修改签署用户密码接口："+json);
		
		// 【获取签署用户单个印章数据】
		json = getSeal(signer_code, seal_code);
		System.out.println("单个印章接口："+json);
		
		// 【获取签署用户的所有印章】
		json = getSeals(signer_code);
		System.out.println("所有印章接口："+json);

	}

	/**
	 * 创建个人用户
	 * @param signer_code 用户编码
	 * @param name 用户名称
	 * @param idcode 用户身份证号码
	 * @param phone 用户手机号码
	 * @return
	 * @throws IOException
	 */
	public static JSONObject createSigner(String signer_code, String name, String idcode,String phone) throws IOException {
		HttpRequest request = MainTest.createHttpRequest("/api/signer/create");
		// 签署用户编码
		request.addParam("signer_code", signer_code);
		// 签署用户名称
		request.addParam("signer_name", name);
		// 签署用户手机号码
		request.addParam("signer_phone", phone);
		// 签署用户身份证号码
		request.addParam("signer_idcode", idcode);

		request.send();
		return JSONObject.parseObject(request.resultToString());
	}

	/**
	 * 创建企业用户
	 * 
	 * @throws IOException
	 */
	public static JSONObject createCompanySigner(String signer_code) throws IOException {

		HttpRequest request = MainTest.createHttpRequest("/api/signer/create");
		// 设置用户编码
		request.addParam("signer_code", signer_code);
		// 设置用户编码
		request.addParam("signer_name", "金格科技股份有限公司");

		request.addParam("signer_phone", "18770066807");

		// 设置企业类型
		request.addParam("signer_type", "2");
		request.addParam("signer_idtype", "2");
		request.addParam("signer_idcode", "9136010674863060XM");
		request.send();

		return JSONObject.parseObject(request.resultToString());
	}

	/**
	 * 签署用户信息修改
	 * 
	 * @param signer_code
	 *            用户编码
	 * @param signer_name
	 *            用户名称（选填）
	 * @param signer_phone
	 *            用户手机号码（选填）
	 * @param signer_type
	 *            用户类型（选填）
	 * @param signer_idtype
	 *            用户证件类型（选填）
	 * @param signer_idcode
	 *            用户证件编号（选填）
	 * @return
	 * @throws IOException
	 */
	public static JSONObject updateSigner(String signer_code, String signer_name, String signer_phone,
			String signer_type, String signer_idtype, String signer_idcode) throws IOException {

		// 设置URL
		HttpRequest request = MainTest.createHttpRequest("/api/signer/update");

		// 设置参数
		request.addParam("signer_code", signer_code);
		request.addParam("signer_name", signer_name);
		request.addParam("signer_phone", signer_phone);
		request.addParam("signer_type", signer_type);
		request.addParam("signer_idtype", signer_idtype);
		request.addParam("signer_idcode", signer_idcode);
		request.send();

		return JSONObject.parseObject(request.resultToString());
	}

	/**
	 * 注册个人用户
	 * @param code 个人用户编码
	 * @param name 个人用户名称
	 * @param idcode  个人用户证件编号
	 * @param phone   个人用户手机号码
	 * @return
	 * @throws IOException
	 */
	public static JSONObject registerPersonlSigner(String code, String name, String idcode,String phone) throws IOException {
		//参数详情请参考接口文档(/api/signer/register)
		HttpRequest request = MainTest.createHttpRequest("/api/signer/register");
		// 签署用户编码
		request.addParam("signer_code", code);
		// 签署用户名称
		request.addParam("signer_name", name);
		// 签署用户手机号码
		request.addParam("signer_phone", phone);
		//签署用户身份类型【1：个人用户，2：企业用户】
		request.addParam("signer_type", "1");
		//签署用户身份类型【0：居民身份证，1：护照，B：港澳居民往来内地通行证，C：台湾居民来往大陆通行证，Z：其他】
		request.addParam("signer_idtype", "0");
		// 签署用户身份证号码
		request.addParam("signer_idcode", idcode);
		// 签署用户证书类型【0：UKEY证书，1：文件证书，2：普通证书，4：事件证书】
		request.addParam("signer_certtype", "4");
				
		request.send();
		return JSONObject.parseObject(request.resultToString());
	}
	
	/**
	 * 
	 * @param code 企业用户编码
	 * @param name 企业用户名称
	 * @param idcode 企业用户证件编号
	 * @param phone 企业用户手机号码
	 * @return
	 * @throws IOException
	 */
	public static JSONObject registerEnterpriseSigner(String code, String name, String idcode,String phone) throws IOException {
		//参数详情请参考接口文档(/api/signer/register)
		HttpRequest request = MainTest.createHttpRequest("/api/signer/register");
		// 签署用户编码
		request.addParam("signer_code", code);
		// 签署用户名称
		request.addParam("signer_name", name);
		// 签署用户手机号码
		request.addParam("signer_phone", phone);
		//签署用户身份类型【1：个人用户，2：企业用户】
		request.addParam("signer_type", "2");
		//签署用户身份类型【2：社会信用代码，3：工商登记证，4：税务登记证，7：组织机构代码证，8：企业营业执照 ，Z：其他】
		request.addParam("signer_idtype", "2");
		// 签署用户身份证号码
		request.addParam("signer_idcode", idcode);
		// 签署用户证书类型【0：UKEY证书，1：文件证书，2：普通证书，4：事件证书】
		request.addParam("signer_certtype", "4");
				
		request.send();
		return JSONObject.parseObject(request.resultToString());
	}
	/**
	 * 修改签署用户密码
	 * 
	 * @param signer_code
	 *            签署用户编码
	 * @param signer_pwd
	 *            原始密码
	 * @param signer_newpwd
	 *            修改后密码
	 * @return
	 * @throws IOException
	 */
	public static JSONObject updateSignerWithPwd(String signer_code, String signer_pwd, String signer_newpwd)
			throws IOException {

		// 设置URL
		HttpRequest request = MainTest.createHttpRequest("/api/signer/updatePwd");

		// 设置参数
		request.addParam("signer_code", signer_code);
		request.addParam("signer_pwd", signer_pwd);
		request.addParam("signer_newpwd", signer_newpwd);

		request.send();
		return JSONObject.parseObject(request.resultToString());

	}

	/**
	 * 获取签署用户单个印章数据
	 * 
	 * @param signer_code
	 *            签署用户编码
	 * @param seal_code
	 *            签署用户的印章编码（选填）
	 * @return
	 * @throws IOException
	 */
	public static JSONObject getSeal(String signer_code, String seal_code) throws IOException {

		// 设置URL
		HttpRequest request = MainTest.createHttpRequest("/api/signer/getSeal");

		// 设置参数
		request.addParam("signer_code", signer_code);
		request.addParam("seal_code", seal_code);
		request.send();

		return JSONObject.parseObject(request.resultToString());
	}

	/**
	 * 获取签署用户的所有印章
	 * 
	 * @param signer_code
	 * @return
	 * @throws IOException
	 */
	public static JSONObject getSeals(String signer_code) throws IOException {

		// 设置URL
		HttpRequest request = MainTest.createHttpRequest("/api/signer/getSeals");

		// 设置参数
		request.addParam("signer_code", signer_code);
		request.send();

		return JSONObject.parseObject(request.resultToString());
	}

	/**
	 * 
	 * @param signer_code  用户编号
	 * @param seal_code  签章编号
	 * @param seal_name  签章名称
	 * @return
	 * @throws IOException
	 */
	public static JSONObject createSeal(String signer_code,String seal_code,String seal_name) throws IOException {
		//参数详情请参考接口文档(/api/signer/register)
		HttpRequest request = MainTest.createHttpRequest("/api/seal/create");

		// 设置参数
		request.addParam("signer_code", signer_code);  //用户编号
		request.addParam("seal_code", signer_code);   //签章编号
		request.addParam("seal_name", seal_name);    //签章名称
		request.addParam("seal_isdefault", "1");	//设置用户默认签章
		request.send();

		return JSONObject.parseObject(request.resultToString());
	}
}
